@@ -12,7 +12,7 @@ import pykka
 from mopidy import settings
 from mopidy.utils import process
 
-from . import mixers
+from . import mixers, utils
 from .constants import PlaybackState
 from .listener import AudioListener
 
@@ -21,6 +21,9 @@ logger = logging.getLogger('mopidy.audio')
 mixers.register_mixers()
 
 
+MB = 1 << 20
+
+
 class Audio(pykka.ThreadingActor):
     """
     Audio output through `GStreamer <http://gstreamer.freedesktop.org/>`_.
@@ -39,16 +42,19 @@ class Audio(pykka.ThreadingActor):
         super(Audio, self).__init__()
 
         self._playbin = None
+        self._signal_ids = {}  # {(element, event): signal_id}
+
         self._mixer = None
         self._mixer_track = None
         self._mixer_scale = None
         self._software_mixing = False
-        self._appsrc = None
         self._volume_set = None
 
-        self._notify_source_signal_id = None
-        self._about_to_finish_id = None
-        self._message_signal_id = None
+        self._appsrc = None
+        self._appsrc_caps = None
+        self._appsrc_need_data_callback = None
+        self._appsrc_enough_data_callback = None
+        self._appsrc_seek_data_callback = None
 
     def on_start(self):
         try:
@@ -65,42 +71,75 @@ class Audio(pykka.ThreadingActor):
         self._teardown_mixer()
         self._teardown_playbin()
 
+    def _connect(self, element, event, *args):
+        """Helper to keep track of signal ids based on element+event"""
+        self._signal_ids[(element, event)] = element.connect(event, *args)
+
+    def _disconnect(self, element, event):
+        """Helper to disconnect signals created with _connect helper."""
+        signal_id = self._signal_ids.pop((element, event), None)
+        if signal_id is not None:
+            element.disconnect(signal_id)
+
     def _setup_playbin(self):
-        self._playbin = gst.element_factory_make('playbin2')
+        playbin = gst.element_factory_make('playbin2')
 
         fakesink = gst.element_factory_make('fakesink')
-        self._playbin.set_property('video-sink', fakesink)
+        playbin.set_property('video-sink', fakesink)
 
-        self._about_to_finish_id = self._playbin.connect(
-            'about-to-finish', self._on_about_to_finish)
-        self._notify_source_signal_id = self._playbin.connect(
-            'notify::source', self._on_new_source)
+        self._connect(playbin, 'about-to-finish', self._on_about_to_finish)
+        self._connect(playbin, 'notify::source', self._on_new_source)
+
+        self._playbin = playbin
 
     def _on_about_to_finish(self, element):
-        self._appsrc = None
+        source, self._appsrc = self._appsrc, None
+        if source is None:
+            return
+        self._appsrc_caps = None
+
+        self._disconnect(source, 'need-data')
+        self._disconnect(source, 'enough-data')
+        self._disconnect(source, 'seek-data')
 
     def _on_new_source(self, element, pad):
         uri = element.get_property('uri')
         if not uri or not uri.startswith('appsrc://'):
             return
 
-        # These caps matches the audio data provided by libspotify
-        default_caps = gst.Caps(
-            b'audio/x-raw-int, endianness=(int)1234, channels=(int)2, '
-            b'width=(int)16, depth=(int)16, signed=(boolean)true, '
-            b'rate=(int)44100')
         source = element.get_property('source')
-        source.set_property('caps', default_caps)
-        # GStreamer does not like unicode
+        source.set_property('caps', self._appsrc_caps)
         source.set_property('format', b'time')
+        source.set_property('stream-type', b'seekable')
+        source.set_property('max-bytes', 1 * MB)
+        source.set_property('min-percent', 50)
+
+        self._connect(source, 'need-data', self._appsrc_on_need_data)
+        self._connect(source, 'enough-data', self._appsrc_on_enough_data)
+        self._connect(source, 'seek-data', self._appsrc_on_seek_data)
 
         self._appsrc = source
 
+    def _appsrc_on_need_data(self, appsrc, gst_length_hint):
+        length_hint = utils.clocktime_to_millisecond(gst_length_hint)
+        if self._appsrc_need_data_callback is not None:
+            self._appsrc_need_data_callback(length_hint)
+        return True
+
+    def _appsrc_on_enough_data(self, appsrc):
+        if self._appsrc_enough_data_callback is not None:
+            self._appsrc_enough_data_callback()
+        return True
+
+    def _appsrc_on_seek_data(self, appsrc, gst_position):
+        position = utils.clocktime_to_millisecond(gst_position)
+        if self._appsrc_seek_data_callback is not None:
+            self._appsrc_seek_data_callback(position)
+        return True
+
     def _teardown_playbin(self):
-        if self._about_to_finish_id:
-            self._playbin.disconnect(self._about_to_finish_id)
-        if self._notify_source_signal_id:
-            self._playbin.disconnect(self._notify_source_signal_id)
+        self._disconnect(self._playbin, 'about-to-finish')
+        self._disconnect(self._playbin, 'notify::source')
         self._playbin.set_state(gst.STATE_NULL)
 
     def _setup_output(self):
@@ -183,28 +222,34 @@ class Audio(pykka.ThreadingActor):
     def _setup_message_processor(self):
         bus = self._playbin.get_bus()
         bus.add_signal_watch()
-        self._message_signal_id = bus.connect('message', self._on_message)
+        self._connect(bus, 'message', self._on_message)
 
     def _teardown_message_processor(self):
-        if self._message_signal_id:
-            bus = self._playbin.get_bus()
-            bus.disconnect(self._message_signal_id)
-            bus.remove_signal_watch()
+        bus = self._playbin.get_bus()
+        self._disconnect(bus, 'message')
+        bus.remove_signal_watch()
 
     def _on_message(self, bus, message):
         if (message.type == gst.MESSAGE_STATE_CHANGED
                 and message.src == self._playbin):
             old_state, new_state, pending_state = message.parse_state_changed()
             self._on_playbin_state_changed(old_state, new_state, pending_state)
+        elif message.type == gst.MESSAGE_BUFFERING:
+            percent = message.parse_buffering()
+            logger.debug('Buffer %d%% full', percent)
         elif message.type == gst.MESSAGE_EOS:
             self._on_end_of_stream()
         elif message.type == gst.MESSAGE_ERROR:
             error, debug = message.parse_error()
-            logger.error('%s %s', error, debug)
+            logger.error(
+                '%s Debug message: %s',
+                str(error).decode('utf-8'), debug.decode('utf-8') or 'None')
             self.stop_playback()
         elif message.type == gst.MESSAGE_WARNING:
             error, debug = message.parse_warning()
-            logger.warning('%s %s', error, debug)
+            logger.warning(
+                '%s Debug message: %s',
+                str(error).decode('utf-8'), debug.decode('utf-8') or 'None')
 
     def _on_playbin_state_changed(self, old_state, new_state, pending_state):
         if new_state == gst.STATE_READY and pending_state == gst.STATE_NULL:
@@ -250,6 +295,32 @@ class Audio(pykka.ThreadingActor):
         """
         self._playbin.set_property('uri', uri)
 
+    def set_appsrc(
+            self, caps, need_data=None, enough_data=None, seek_data=None):
+        """
+        Switch to using appsrc for getting audio to be played.
+
+        You *MUST* call :meth:`prepare_change` before calling this method.
+
+        :param caps: GStreamer caps string describing the audio format to
+            expect
+        :type caps: string
+        :param need_data: callback for when appsrc needs data
+        :type need_data: callable which takes data length hint in ms
+        :param enough_data: callback for when appsrc has enough data
+        :type enough_data: callable
+        :param seek_data: callback for when data from a new position is needed
+            to continue playback
+        :type seek_data: callable which takes time position in ms
+        """
+        if isinstance(caps, unicode):
+            caps = caps.encode('utf-8')
+        self._appsrc_caps = gst.Caps(caps)
+        self._appsrc_need_data_callback = need_data
+        self._appsrc_enough_data_callback = enough_data
+        self._appsrc_seek_data_callback = seek_data
+        self._playbin.set_property('uri', 'appsrc://')
+
     def emit_data(self, buffer_):
         """
         Call this to deliver raw audio data to be played.
@@ -282,13 +353,11 @@ class Audio(pykka.ThreadingActor):
 
         :rtype: int
         """
-        if self._playbin.get_state()[1] == gst.STATE_NULL:
-            return 0
         try:
-            position = self._playbin.query_position(gst.FORMAT_TIME)[0]
-            return position // gst.MSECOND
-        except gst.QueryError, e:
-            logger.error('time_position failed: %s', e)
+            gst_position = self._playbin.query_position(gst.FORMAT_TIME)[0]
+            return utils.clocktime_to_millisecond(gst_position)
+        except gst.QueryError:
+            logger.debug('Position query failed')
             return 0
 
     def set_position(self, position):
@@ -299,12 +368,9 @@ class Audio(pykka.ThreadingActor):
         :type position: int
         :rtype: :class:`True` if successful, else :class:`False`
         """
-        self._playbin.get_state()  # block until state changes are done
-        handeled = self._playbin.seek_simple(
-            gst.Format(gst.FORMAT_TIME), gst.SEEK_FLAG_FLUSH,
-            position * gst.MSECOND)
-        self._playbin.get_state()  # block until seek is done
-        return handeled
+        gst_position = utils.millisecond_to_clocktime(position)
+        return self._playbin.seek_simple(
+            gst.Format(gst.FORMAT_TIME), gst.SEEK_FLAG_FLUSH, gst_position)
 
     def start_playback(self):
         """
