@@ -35,7 +35,11 @@ class LocalLibraryProvider(base.BaseLibraryProvider):
             logger.debug('Failed to lookup %r', uri)
             return []
 
-    def find_exact(self, **query):
+    def find_exact(self, query=None, uris=None):
+        # TODO Only return results within URI roots given by ``uris``
+
+        if query is None:
+            query = {}
         self._validate_query(query)
         result_tracks = self._uri_mapping.values()
 
@@ -72,7 +76,11 @@ class LocalLibraryProvider(base.BaseLibraryProvider):
                     raise LookupError('Invalid lookup field: %s' % field)
         return SearchResult(uri='file:search', tracks=result_tracks)
 
-    def search(self, **query):
+    def search(self, query=None, uris=None):
+        # TODO Only return results within URI roots given by ``uris``
+
+        if query is None:
+            query = {}
         self._validate_query(query)
         result_tracks = self._uri_mapping.values()
 
