@@ -20,8 +20,7 @@ https://github.com/mopidy/mopidy/issues?labels=Spotify+backend
 
 **Dependencies:**
 
-- libspotify >= 12, < 13 (libspotify12 package from apt.mopidy.com)
-- pyspotify >= 1.9, < 1.11 (python-spotify package from apt.mopidy.com)
+.. literalinclude:: ../../../requirements/spotify.txt
 
 **Settings:**
 
