@@ -329,7 +329,7 @@ def seek(context, songpos, seconds):
 
     - issues ``seek 1 120`` without quotes around the arguments.
     """
-    if context.core.playback.tracklist_position.get() != songpos:
+    if context.core.playback.tracklist_position.get() != int(songpos):
         playpos(context, songpos)
     context.core.playback.seek(int(seconds) * 1000).get()
 
@@ -344,11 +344,31 @@ def seekid(context, tlid, seconds):
         Seeks to the position ``TIME`` (in seconds) of song ``SONGID``.
     """
     tl_track = context.core.playback.current_tl_track.get()
-    if not tl_track or tl_track.tlid != tlid:
+    if not tl_track or tl_track.tlid != int(tlid):
         playid(context, tlid)
     context.core.playback.seek(int(seconds) * 1000).get()
 
 
+@handle_request(r'^seekcur "(?P<position>\d+)"$')
+@handle_request(r'^seekcur "(?P<diff>[-+]\d+)"$')
+def seekcur(context, position=None, diff=None):
+    """
+    *musicpd.org, playback section:*
+
+        ``seekcur {TIME}``
+
+        Seeks to the position ``TIME`` within the current song. If prefixed by
+        '+' or '-', then the time is relative to the current playing position.
+    """
+    if position is not None:
+        position = int(position) * 1000
+        context.core.playback.seek(position).get()
+    elif diff is not None:
+        position = context.core.playback.time_position.get()
+        position += int(diff) * 1000
+        context.core.playback.seek(position).get()
+
+
 @handle_request(r'^setvol (?P<volume>[-+]*\d+)$')
 @handle_request(r'^setvol "(?P<volume>[-+]*\d+)"$')
 def setvol(context, volume):
